==> haskell-lrucache-1.2.0.1-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lrucache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lrucache
version:              1.2.0.1
visibility:           public
id:                   lrucache-1.2.0.1-IhAKoj2aSIn4IdWR0Y4Dsu
key:                  lrucache-1.2.0.1-IhAKoj2aSIn4IdWR0Y4Dsu
license:              BSD-3-Clause
copyright:            Carl Howells, 2010-2015
maintainer:           chowells79@gmail.com
author:               Carl Howells
stability:            Experimental
homepage:             http://github.com/chowells79/lrucache
synopsis:             a simple, pure LRU cache
description:
    This package contains a simple, pure LRU cache, implemented in
    terms of "Data.Map".

    It also contains a mutable IO wrapper providing atomic updates to
    an LRU cache.

category:             Data
abi:                  cac5230d4b6b787310da1c2deb1b13be
exposed:              True
exposed-modules:
    Data.Cache.LRU Data.Cache.LRU.IO Data.Cache.LRU.IO.Internal
    Data.Cache.LRU.Internal

import-dirs:          /usr/lib/ghc-9.0.2/site-local/lrucache-1.2.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/lrucache-1.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/lrucache-1.2.0.1
hs-libraries:         HSlrucache-1.2.0.1-IhAKoj2aSIn4IdWR0Y4Dsu
depends:
    base-4.15.1.0 containers-0.6.4.1
    contravariant-1.5.5-FtJyCLyWfutGN2UWoJs8qd

haddock-interfaces:   /usr/share/doc/haskell-lrucache/html/lrucache.haddock
haddock-html:         /usr/share/doc/haskell-lrucache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lrucache-1.2.0.1-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lrucache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lrucache
version:              1.2.0.1
visibility:           public
id:                   lrucache-1.2.0.1-85TckKKmxOiF6EAQ5zFLML
key:                  lrucache-1.2.0.1-85TckKKmxOiF6EAQ5zFLML
license:              BSD-3-Clause
copyright:            Carl Howells, 2010-2015
maintainer:           chowells79@gmail.com
author:               Carl Howells
stability:            Experimental
homepage:             http://github.com/chowells79/lrucache
synopsis:             a simple, pure LRU cache
description:
    This package contains a simple, pure LRU cache, implemented in
    terms of "Data.Map".

    It also contains a mutable IO wrapper providing atomic updates to
    an LRU cache.

category:             Data
abi:                  3b3fb8b2ce0fb5bcb769a06615dd333e
exposed:              True
exposed-modules:
    Data.Cache.LRU Data.Cache.LRU.IO Data.Cache.LRU.IO.Internal
    Data.Cache.LRU.Internal

import-dirs:          /usr/lib/ghc-9.2.8/site-local/lrucache-1.2.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/lrucache-1.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lrucache
hs-libraries:         HSlrucache-1.2.0.1-85TckKKmxOiF6EAQ5zFLML
depends:
    base-4.16.4.0 containers-0.6.5.1
    contravariant-1.5.5-6oWUjmJNxDBFhugVD5s9dq

haddock-interfaces:   /usr/share/doc/haskell-lrucache/html/lrucache.haddock
haddock-html:         /usr/share/doc/haskell-lrucache/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
